PipelineResult
==============

.. currentmodule:: pykeen.pipeline

.. autoclass:: PipelineResult
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PipelineResult.stopper
      ~PipelineResult.title

   .. rubric:: Methods Summary

   .. autosummary::

      ~PipelineResult.get_metric
      ~PipelineResult.plot
      ~PipelineResult.plot_early_stopping
      ~PipelineResult.plot_er
      ~PipelineResult.plot_losses
      ~PipelineResult.save_model
      ~PipelineResult.save_to_directory
      ~PipelineResult.save_to_ftp
      ~PipelineResult.save_to_s3

   .. rubric:: Attributes Documentation

   .. autoattribute:: stopper
   .. autoattribute:: title

   .. rubric:: Methods Documentation

   .. automethod:: get_metric
   .. automethod:: plot
   .. automethod:: plot_early_stopping
   .. automethod:: plot_er
   .. automethod:: plot_losses
   .. automethod:: save_model
   .. automethod:: save_to_directory
   .. automethod:: save_to_ftp
   .. automethod:: save_to_s3
